@@ -1,6 +1,5 @@
-# -*- coding: utf-8 -*-
+# -*- encoding: utf-8 -*-
 
-from django.conf import settings
 from djmail import core
 
 from . import base
